Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrListenerIsOff ... ErrListenerIsOff = errors.New("listener is off") )
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// AuthManager
AuthManager *auth.Manager
Host string
// Port tcp port to listen on
Port string
}
Config is base configuration object used by all transports
type ConfigTCP ¶
ConfigTCP configuration of tcp transport
func NewConfigTCP ¶
NewConfigTCP allocate new transport config for tcp transport Use of this function is preferable instead of direct allocation of ConfigTCP
type ConfigWS ¶
type ConfigWS struct {
// CertFile
CertFile string
// KeyFile
KeyFile string
// Path
Path string
// SubProtocols
SubProtocols []string
// contains filtered or unexported fields
}
ConfigWS listener object for websocket server
func NewConfigWS ¶
NewConfigWS allocate new transport config for websocket transport Use of this function is preferable instead of direct allocation of ConfigWS
type InternalConfig ¶
type InternalConfig struct {
Handler
// EPoll netpoll.EventPoll
AcceptPool types.Pool
Metric systree.Metric
}
InternalConfig used by server implementation to configure internal specific needs
type Provider ¶
type Provider interface {
Protocol() string
Serve() error
Close() error
Port() string
Ready() error
Alive() error
}
Provider is interface that all of transports must implement
Click to show internal directories.
Click to hide internal directories.